from dlmr_tools.data_tool import Data
from dlmr_tools.graph_tool import Graph_1D

from dataclasses import dataclass


@dataclass
class GraphManager:
    __datasheet_name: str = "spreadsheet.xlsx"
    __output_folder: str = "results"
    __sheet_names = ["Sheet 1", "Sheet 2"]
    __data = dict()
    
    def __post_init__(self) -> None:
        self.__spreadsheet = Data(
            data_path=self.__datasheet_name,
            sheet_name=self.__sheet_names
        )
        
        self.__data["x_values"] : list = self.__spreadsheet.get_list(sheet_name=self.__sheet_names[0], list_name="Label x")
        self.__data["y_values"]: list = self.__spreadsheet.get_list(sheet_name=self.__sheet_names[0], list_name="Label y")
        
    def plot_graphs(self) -> None:
        """
        Call all the plot functions.
        """
        self.plot_example()
        
    def plot_example(self) -> None:
        """
        Example of a plot function.
        """
        graph = Graph_1D(figsize=(5, 3), fontsize=9)
        graph.setup_axis(xlabel="x [SI]", ylabel="y [SI]", sci=False)
        graph.plot(x=self.__data["x_values"], y=self.__data["y_values"], label="Curve 1", marker='', linestyle='-', color='chartjs_blue')
        graph.save(filename=self.__output_folder + "/example.png", dx=0.15)
        graph.delete()

if __name__ == "__main__":
    graph_manager = GraphManager()
    graph_manager.plot_graphs()


import shutil
import sys
import os

def generate_template() -> None:
    """
    Copy the file template.py from the directory of this module to the current directory.
    """
    module_dir = os.path.dirname(os.path.abspath(__file__))
    template_file = os.path.join(module_dir, "./templates/template.py")
    
    try:
        shutil.copyfile(template_file, "main.py")
        print("Template copied successfully!")
    except FileNotFoundError:
        print("Error: 'template.py' file not found in the module directory.")
        sys.exit(1)

if __name__ == "__main__":
    generate_template()


import pandas as pd

from .list import List

__all__ = ["Data"]

class Data(object):
    def __init__(self, data_path: str, sheet_name: list = None):
        """Data class for loading data from data_path which is a .xlsx file"""
        self.__data_path = data_path
        self.__sheet_name = sheet_name
        self.__data = self.__load_data()

    def __load_data(self) -> pd.DataFrame:
        """Load data from data_path"""
        return pd.read_excel(self.__data_path, sheet_name=self.__sheet_name)

    def __get_data_sheet(self, sheet_name: str) -> pd.DataFrame:
        """Return data"""
        if sheet_name not in self.__data.keys():
            raise Exception(f"sheet_name '{sheet_name}' not in {self.__data.keys()}")
        return self.__data[sheet_name]
    
    def get_list(self, sheet_name: str, list_name: str, kind: str = None, type: str = float) -> list:
        """
        Return a list from sheet_name with the label list_name.
        Clear the list before returning it.
        """
        page = self.__get_data_sheet(sheet_name)
        all_column = self.__get_all_column(page, list_name)
        list_column = List(all_column, list_name)
        all_raw = self.__get_all_raw(page, list_name)
        list_raw = List(all_raw, list_name)
        if kind is None:
            final_list = list_column.clear()
            if final_list != []:
                return final_list
            all_raw = self.__get_all_raw(page, list_name)
            list_raw = List(all_raw, list_name)
            final_list = list_raw.clear()
            if final_list != []:
                return final_list
            return None
        if kind == "column":
            final_list = list_column.clear()
            if final_list != []:
                return final_list
            return None
        if kind == "row":
            final_list = list_raw.clear()
            if final_list != []:
                return final_list
            return None
        raise Exception(f"kind '{kind}' not in ['column', 'row']")
    
    def __get_all_column(self, page: pd.DataFrame, list_name: str) -> list:
        """Return all column as a list"""
        for i in range(page.shape[0]):
            for j in range(page.shape[1]):
                if page.iloc[i, j] == list_name:
                    return page.iloc[:, j].tolist()
        raise Exception(f"list_name '{list_name}' not in this page")
    
    def __get_all_raw(self, page: pd.DataFrame, list_name: str) -> list:
        """Return all raw as a list"""
        for i in range(page.shape[0]):
            for j in range(page.shape[1]):
                if page.iloc[i, j] == list_name:
                    return page.iloc[i, :].tolist()
        raise Exception(f"list_name '{list_name}' not in this page")